function value = objective_function(x, quad_solution_selector)
    global p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 psi;

    a = x(1);
    b = x(2);
    
    %% Solving for d, return large number if solution is imaginary
    [d, error_flag] = solving_E0_for_d(a,b,quad_solution_selector);
    if error_flag == 1
        value = Inf;
        return;
    end

    %% Solving for remaining parameters and assigning new names
    c = -a - 2 * psi;
    e = c;
    f = (b * p7 * cos((2 * a + 2 * psi)) - d * p9) / p8;
    g = a;
    h = (p7 ^ 2 / p8 / p11 * cos((2 * a + 2 * psi)) ^ 2 ...
        - p6 / p11) * b + (p8 * p10 - p9 * p7)...
        / p8 / p11 * cos((2 * a + 2 * psi)) * d;

    theta0 = a;
    thetaT = c;
    Dtheta0 = b;
    DthetaT = d;

    phi0 = e;
    phiT = g;
    Dphi0 = f/b;
    DphiT = h/d;

    %% Solving phi'' = f0 for inital conditions
    E0 = -f * cos(a - e) * p2 * b + f ^ 2 * p3 / 0.2e1 + ...
        p1 * b ^ 2 / 0.2e1 + cos(a) * p4 + p5 - cos(e) * p5 - p4;
    
    options = odeset('reltol',1e-9,'abstol',1e-6);
    [thetaout, yout] = ode45(@(theta,y) f0(theta,y,E0), ...
                              [theta0; thetaT], ...
                              [phi0; Dphi0], options);
   
    %% Returning objective function value
    value = (thetaout(end) - thetaT)^2 ...
            + (yout(end,1) - phiT)^2 + (yout(end,2) - DphiT)^2;
end

