function [a,b,c,d,e,f,g,h,E0] = run_gait_search(...
                                    a0,b0,quad_solution_selector)
                                
    global p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 psi;
    
    run physical_parameters;
    fprintf('*********************************************\n');
    fprintf('SEARCHING FOR PERIODIC GAIT OF PASSIVE WALKER\n');
    fprintf('*********************************************\n');
    fprintf('Starting search with initial guess:\n');
    fprintf('q10 = %f\nDq10 = %f\n', a0,b0);
    fprintf('***********************************\n');
    
    x0 = [a0; b0];

    % Searching for intitial values q10 = a, Dq10 = b
    xout = fminsearch(@(x) objective_function(x, ...
                      quad_solution_selector),...
                      x0, optimset('Display','iter','TolFun',1e-10));

    a = xout(1);
    b = xout(2);

    % Finding corresponding values dq20 = e, Dq20 = f
    c = -a - 2 * psi;
    e = c;

    d = solving_E0_for_d(a,b,quad_solution_selector);
    f = (b * p7 * cos((2 * a + 2 * psi)) - d * p9) / p8;

    g = a;
    h = (p7 ^ 2 / p8 / p11 * cos((2 * a + 2 * psi)) ^ 2 - p6 / p11)...
        * b + (p8 * p10 - p9 * p7) / p8 / p11...
        * cos((2 * a + 2 * psi)) * d;

    E0 = -f * cos(a - e) * p2 * b + f ^ 2 * p3 / 0.2e1 + p1 *...
        b ^ 2 / 0.2e1 + cos(a) * p4 + p5 - cos(e) * p5 - p4;

    % Complete initial conditions for gait
    fprintf('*********************\n');
    fprintf('Optimization results:\n');
    fprintf('*********************\n');
    fprintf('a = %f\nb = %f\nc = %f\nd = %f\ne = %f\n',a, b, c, d, e);
    fprintf('f = %f\ng = %f\nh = %f\nE0 = %f\n', f, g, h, E0);
    fprintf('******************\n');
    fprintf('q10 = %f\nq20 = %f\nDq10 = %f\nDq20 = %f\n', a,e,b,f);
    fprintf('******************\n\n');

end


