function [d, error_flag] = solving_E0_for_d(a,b,quad_solution_selector)
    global p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 psi;
    
    error_flag = 0;

    %% Solving for d = Dq1T using the quadratic formula
    % E0d = A2*d^2 + B2*d + C2

    A2 = (p8 * p10 - p9 * p7) ^ 2 / p8 ^ 2 / p11 ^ 2 *...
        cos((2 * a + 2 * psi)) ^ 2 * p3 / 0.2e1 - p9 ^ 2 ...
        / p8 ^ 2 * p3 / 0.2e1 + p1 / 0.2e1 - (p8 * p10 - p9 * p7)...
        / p8 / p11 * cos((2 * a + 2 * psi)) ^ 2 * p2;
    B2 = -p9 / p8 * cos((2 * a + 2 * psi)) * p2 * b ...
        - (p7 ^ 2 / p8 / p11 * cos((2 * a + 2 * psi)) ^ 2 ...
        - p6 / p11) * b * cos((2 * a + 2 * psi)) * p2 ...
        + (p7 ^ 2 / p8 / p11 * cos((2 * a + 2 * psi)) ^ 2 ...
        - p6 / p11) * b * (p8 * p10 - p9 * p7) / p8 / p11 ...
        * cos((2 * a + 2 * psi)) * p3 +...
        b * p7 * cos((2 * a + 2 * psi)) * p9 / p8 ^ 2 * p3;
    C2 = -p1 * b ^ 2 / 0.2e1 - cos(a) * p4 + ...
        (p7 ^ 2 / p8 / p11 * cos(0.2e1 * a + ...
        (2 * psi)) ^ 2 - p6 / p11) ^ 2 * b ^ 2 ...
        * p3 / 0.2e1 - cos(a) * p5 + b ^ 2 * p7 ...
        * cos(0.2e1 * a + (2 * psi)) ^ 2 / p8 * p2...
        + cos(a + (2 * psi)) * p4 + cos(a + (2 * psi)) ...
        * p5 - b ^ 2 * p7 ^ 2 * cos(0.2e1 * a ...
        + (2 * psi)) ^ 2 / p8 ^ 2 * p3 / 0.2e1;


    % Standard solution of the quadratic equation
    % d = (-B2 +- sqrt(B2^2-4*A2*C2))/(2*A2) 
    D2 = B2^2-4*A2*C2;

    if D2 < 0 % Imaginary solution
        error_flag = 1;
        d = NaN;
        return;
    end
    
    % Switching between the 2 possible solutions of the 
    % quadratic equation
    switch quad_solution_selector
        case 1
            d = (-B2 + sqrt(D2))/(2*A2); 
        case 2
            d = (-B2 - sqrt(D2))/(2*A2); 
        otherwise
            d = NaN;
            error_flag = 1;
    end
end

