function [x_plus] = impact_map(x_minus, map_selector)
    global p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 psi;
    
    q1 = x_minus(1);
    q2 = x_minus(2);
    Dq1 = x_minus(3);
    Dq2 = x_minus(4);
    
    switch map_selector
        case 1
            %% Impulse map using conservation of angular momentum

            Qp = [-cos(q1 - q2) * p7 + p6 p8 - cos(q1 - q2) * p7; ...
                -cos(q1 - q2) * p7 p8;];
            Qn = [cos(q1 - q2) * p10 - p9 -p11; -p9 0;];

            Dq_plus = Qp\Qn*[Dq1; Dq2];
    
        case 2
            %% Impulse map using method from Grizzle, Abba, Plestan 2001
            
            [mH, m1, m2, a, b, l, g] = physical_parameters;
        
            A = [mH * l ^ 2 + b ^ 2 * m1 + l ^ 2 * m2 -a * l * m2 ...
                * cos(q1 - q2) -cos(q1) * (mH * l + b * m1 + l * m2)...
                -sin(q1) * (mH * l + b * m1 + l * m2) l * cos(q1) l ...
                * sin(q1); -a * l * m2 * cos(q1 - q2) a ^ 2 * m2 a ...
                * m2 * cos(q2) a * m2 * sin(q2) -l * cos(q2) -l ...
                * sin(q2); -cos(q1) * (mH * l + b * m1 + l * m2) a ...
                * m2 * cos(q2) m1 + m2 + mH 0 -1 0; -sin(q1) ...
                * (mH * l + b * m1 + l * m2) a * m2 * sin(q2) 0 m1...
                + m2 + mH 0 -1; -l * cos(q1) l * cos(q2) 1 0 0 0; ...
                -l * sin(q1) l * sin(q2) 0 1 0 0;];
            B = [(mH * l ^ 2 + b ^ 2 * m1 + l ^ 2 * m2) * Dq1 ...
                - m2 * l * a * cos(q1 - q2) * Dq2 -m2 * l * Dq1 ...
                * a * cos(q1 - q2) + a ^ 2 * m2 * Dq2 -cos(q1) ...
                * (mH * l + b * m1 + l * m2) * Dq1 + a ...
                * m2 * cos(q2) * Dq2 -sin(q1) ...
                * (mH * l + b * m1 + l * m2) * Dq1 ...
                + a * m2 * sin(q2) * Dq2 0 0];
        
            z = A\B';
            Dq_plus=[z(2);z(1)];
    
        case 3
            %% Impulse map using method described by Shiriaev
            % BUG: DOES NOT YIELD CORRECT RESULTS
            
            [mH, m1, m2, a, b, l, g] = physical_parameters;
            
            A = [0 0 0 0 0 0; 0 0 0 0 0 0; m1 * a ^ 2 m1 * a * l ...
                * cos(-q2 + q1) 0 0 0 0; 0 m2 * b ^ 2 - m2 * b ...
                * l l * cos(q2) l * sin(q2) 0 0; -m1 * a ^ 2 ...
                * cos(q1) / l -m1 * a * (cos(0.2e1 * q1 - q2)...
                + cos(q2)) / 0.2e1 0 0 0 -0.2e1 * l * sin(q1);...
                -m1 * a ^ 2 * sin(q1) / l -m1 * a * (sin(0.2e1 ...
                * q1 - q2) + sin(q2)) / 0.2e1 0 0 0 0.2e1 * l ...
                * cos(q1); 0 -0.1e1 / l * m2 * b * cos(q2) ...
                * (b + l) -1 0 -0.2e1 * l * sin(q2) 0; 0 -0.1e1 ...
                / l * m2 * b * sin(q2) * (b + l) 0 -1 0.2e1 ...
                * l * cos(q2) 0; 0.1e1 / l * m1 * a * cos(q1) ...
                * (a + l) (0.2e1 * m1 * l ^ 2 * cos(q2) + m1 ...
                * a * l * cos(0.2e1 * q1 - q2) + m1 * l * cos(q2) ...
                * a + 0.2e1 * m2 * b ^ 2 * cos(q2) + 0.2e1 ...
                * mH * l ^ 2 * cos(q2)) / l / 0.2e1 0 0 0.2e1 ...
                * l * sin(q2) 0.2e1 * l * sin(q1); 0.1e1 / l ...
                * m1 * a * sin(q1) * (a + l) (m1 * a * l ...
                * sin(0.2e1 * q1 - q2) + 0.2e1 * m1 * l ^ 2 ...
                * sin(q2) + m1 * l * sin(q2) * a + 0.2e1 * m2 ...
                * b ^ 2 * sin(q2) + 0.2e1 * mH * l ^ 2 * sin(q2)) ...
                / l / 0.2e1 0 0 -0.2e1 * l * cos(q2) -0.2e1 ...
                * l * cos(q1);];
            B = [0 0 -m1 * a ^ 2 * Dq1 + m1 * a * Dq1 * l -m2 ...
                * b * l * Dq1 * cos(-q2 + q1) - m2 * b ^ 2 ...
                * Dq2 + 0.2e1 * m2 * b * l * Dq2 + m2 * l ^ 2 ...
                * Dq1 * cos(-q2 + q1) - m2 * l ^ 2 * Dq2 0 0 0 0 0 0];    
            
            z = A\B';
            
            Dq_plus=[z(2);z(1)];
   
    end

    %% Updated state vector
    
    q_plus = [q2; q1];   
    x_plus = [q_plus; Dq_plus];

end

