function Dzeta = transverse_linearization_continuous(t, zeta, ...
                theta_inputs_to_phi, phi_evaluated_at_theta, ...
                Dphi_evaluated_at_theta, time_inputs_to_theta, ...
                theta_evaluated_at_time, Dtheta_evaluated_at_time, E0)
    
    global p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 psi;
    
    % Solving for virtual holonomic constraints
    theta = interp1(time_inputs_to_theta,theta_evaluated_at_time, ...
                    t,'spline');
    Dtheta = interp1(time_inputs_to_theta,Dtheta_evaluated_at_time, ...
                    t,'spline');
    temp = aby_weighted(t,[theta; Dtheta], theta_inputs_to_phi, ...
                         phi_evaluated_at_theta, Dphi_evaluated_at_theta);
    DDtheta = temp(2);
    
    phi = interp1(theta_inputs_to_phi,phi_evaluated_at_theta,...
                    theta,'spline');
    Dphi = interp1(theta_inputs_to_phi,Dphi_evaluated_at_theta,...
                    theta,'spline');
    temp = f0(theta, [phi; Dphi], E0);
    DDphi = temp(2);
  
    % Linearized transversal dynamics
    a11 = -0.2e1 * Dtheta / (p1 * p3 - cos(-theta + phi) ^ 2 * p2 ^ 2)...
        * sin(-theta + phi) * p2 * (Dphi ^ 2 * p3 - p2 ...
        * cos(-theta + phi));
    a12 = 0.2e1 * Dtheta / (p1 * p3 - cos(-theta + phi) ^ 2 * p2 ^ 2) ...
        * p2 * (-0.2e1 * Dtheta ^ 2 * p2 ^ 2 * cos(-theta + phi) ...
        * Dphi ^ 2 * p3 + Dtheta ^ 2 * cos(-theta + phi) ^ 3 * ...
        p2 ^ 2 * Dphi ^ 2 * p3 + Dtheta ^ 2 * p2 ^ 3 *...
        cos(-theta + phi) ^ 2 + Dtheta ^ 2 * p1 * p3 ^ 2 ...
        * cos(-theta + phi) * Dphi ^ 2 + Dtheta ^ 2 * p1 * p3 ...
        * p2 - 0.2e1 * Dtheta ^ 2 * p1 * p3 * p2 *...
        cos(-theta + phi) ^ 2 + 0.2e1 * p2 * cos(-theta + phi)...
        * sin(-theta + phi) * sin(theta) * p4 * p3 - p2 ^ 2 ...
        * cos(-theta + phi) ^ 2 * sin(-theta + phi) * sin(phi) ...
        * p5 - p5 * p1 * p3 * sin(-theta + phi) * sin(phi) ...
        + p5 * p1 * p3 * cos(-theta + phi) * cos(phi) - p5 ...
        * cos(-theta + phi) ^ 3 * p2 ^ 2 * cos(phi)) ...
        / (-p1 * p3 + cos(-theta + phi) ^ 2 * p2 ^ 2);
    a13 = 0.4e1 * Dtheta ^ 2 / ...
        (-p1 * p3 + cos(-theta + phi) ^ 2 * p2 ^ 2)...
        * sin(-theta + phi) * p2 * Dphi * p3;
    a21 = 0;
    a22 = 0;
    a23 = 1;
    a31 = (-((-cos(theta) * p4 * p3 * Dphi - sin(theta) * p4 * p3...
        * DDphi + cos(theta) * p4 * p2 * cos(-theta + phi)...
        + sin(theta) * p4 * p2 * sin(-theta + phi) + sin(phi)...
        * p5 * DDphi * cos(-theta + phi) * p2 + sin(phi) ...
        * p5 * Dphi * sin(-theta + phi) * p2) ...
        / (-p1 * p3 + cos(-theta + phi) ^ 2 * p2 ^ 2) ...
        / (E0 - cos(theta) * p4 - p5 + cos(phi) * p5 + p4) ...
        * (-0.2e1 * Dphi * cos(-theta + phi) * p2 + Dphi ^ 2 ...
        * p3 + p1) * Dtheta ^ 2 / 0.2e1 - (-sin(theta) * p4 ...
        * p3 * Dphi + sin(theta) * p4 * p2 * cos(-theta + phi)...
        + sin(phi) * p5 * Dphi * cos(-theta + phi)...
        * p2 - sin(phi) * p5 * p1) / (-p1 * p3 ...
        + cos(-theta + phi) ^ 2 * p2 ^ 2) ^ 2 / (E0 - cos(theta)...
        * p4 - p5 + cos(phi) * p5 + p4) * (-0.2e1 * Dphi ...
        * cos(-theta + phi) * p2 + Dphi ^ 2 * p3 + p1) ...
        * Dtheta ^ 2 * cos(-theta + phi) * p2 ^ 2 ...
        * sin(-theta + phi) - (-sin(theta) * p4 * p3 * Dphi ...
        + sin(theta) * p4 * p2 * cos(-theta + phi) + sin(phi)...
        * p5 * Dphi * cos(-theta + phi) * p2 - sin(phi) * p5 * p1)...
        / (-p1 * p3 + cos(-theta + phi) ^ 2 * p2 ^ 2) ...
        / (E0 - cos(theta) * p4 - p5 + cos(phi) * p5 + p4) ^ 2 ...
        * (-0.2e1 * Dphi * cos(-theta + phi) * p2...
        + Dphi ^ 2 * p3 + p1) * Dtheta ^ 2 * sin(theta) ...
        * p4 / 0.2e1 + (-sin(theta) * p4 * p3 * Dphi ...
        + sin(theta) * p4 * p2 * cos(-theta + phi) + sin(phi)...
        * p5 * Dphi * cos(-theta + phi) * p2 - sin(phi) * p5 * p1)...
        / (-p1 * p3 + cos(-theta + phi) ^ 2 * p2 ^ 2) ...
        / (E0 - cos(theta) * p4 - p5 + cos(phi) * p5 + p4) ...
        * (-0.2e1 * DDphi * cos(-theta + phi) * p2 - 0.2e1 ...
        * Dphi * sin(-theta + phi) * p2 + 0.2e1 * Dphi * p3 ...
        * DDphi) * Dtheta ^ 2 / 0.2e1 - (-cos(theta) * p4 * p3 ...
        * Dphi - sin(theta) * p4 * p3 * DDphi + cos(theta) * p4 ...
        * p2 * cos(-theta + phi) + sin(theta) * p4 * p2 ...
        * sin(-theta + phi) + sin(phi) * p5 * DDphi ...
        * cos(-theta + phi) * p2 + sin(phi) * p5 * Dphi ...
        * sin(-theta + phi) * p2) / (-p1 * p3 ...
        + cos(-theta + phi) ^ 2 * p2 ^ 2) + 0.2e1 * (-sin(theta)...
        * p4 * p3 * Dphi + sin(theta) * p4 * p2 * cos(-theta + phi)...
        + sin(phi) * p5 * Dphi * cos(-theta + phi) * p2 ...
        - sin(phi) * p5 * p1) / (-p1 * p3 + cos(-theta + phi) ^ 2 ...
        * p2 ^ 2) ^ 2 * cos(-theta + phi) * p2 ^ 2 ...
        * sin(-theta + phi)) * DDtheta + (-sin(theta) * p4 * p3 ...
        * Dphi + sin(theta) * p4 * p2 * cos(-theta + phi) + sin(phi)...
        * p5 * Dphi * cos(-theta + phi) * p2 - sin(phi) * p5 * p1)...
        / (-p1 * p3 + cos(-theta + phi) ^ 2 * p2 ^ 2) ...
        / (E0 - cos(theta) * p4 - p5 + cos(phi) * p5 + p4) ...
        * (-0.2e1 * Dphi * cos(-theta + phi) * p2 + Dphi ^ 2 ...
        * p3 + p1) * Dtheta ^ 2) / (0.2e1 * DDtheta ^ 2 ...
        + 0.2e1 * Dtheta ^ 2);
    a32 = ((Dphi * p2 ^ 4 + p2 ^ 4 * Dphi ^ 2) * Dtheta ^ 2 ...
        * cos(-theta + phi) ^ 4 + (-p2 ^ 3 * cos(phi) * Dphi * p5 ...
        + (-p3 * Dphi ^ 3 * p2 ^ 3 - p2 ^ 3 * p1) * Dtheta ^ 2) ...
        * cos(-theta + phi) ^ 3 + (cos(phi) * p5 * p1 * p2 ^ 2 ...
        - p2 ^ 3 * sin(-theta + phi) * sin(theta) * p4 ...
        + (Dphi * p2 ^ 4 + p2 ^ 4 * Dphi ^ 2) * Dtheta ^ 2 ...
        * sin(-theta + phi) ^ 2 - Dphi * p2 ^ 3 * sin(-theta + phi) ...
        * sin(phi) * p5 + (-Dphi * p2 ^ 2 * p1 * p3 - p2 ^ 2 ...
        * Dphi ^ 2 * p1 * p3) * Dtheta ^ 2) * cos(-theta + phi) ^ 2 ...
        + (p2 * cos(phi) * Dphi * p5 * p1 * p3 + 0.2e1 * p2 ^ 2 ...
        * sin(-theta + phi) * sin(theta) * p4 * p3 * Dphi + (-0.2e1 ...
        * p2 ^ 3 * p1 - 0.2e1 * p3 * Dphi ^ 3 * p2 ^ 3) * Dtheta ^ 2 ...
        * sin(-theta + phi) ^ 2 + 0.2e1 * p2 ^ 2 * sin(-theta + phi) ...
        * sin(phi) * p5 * p1 + (p2 * p1 ^ 2 * p3 + p3 ^ 2 * Dphi ^ 3 ...
        * p2 * p1) * Dtheta ^ 2) * cos(-theta + phi) ...
        - cos(phi) * p5 * p1 ^ 2 * p3 - p2 * sin(-theta + phi) ...
        * sin(theta) * p4 * p1 * p3 + (Dphi * p2 ^ 2 * p1 * p3 ...
        + p2 ^ 2 * Dphi ^ 2 * p1 * p3) * Dtheta ^ 2 ...
        * sin(-theta + phi) ^ 2 - Dphi * p2 * sin(-theta + phi) ...
        * sin(phi) * p5 * p1 * p3) / (-p1 * p3 ...
        + cos(-theta + phi) ^ 2 * p2 ^ 2) ^ 2;
    a33 = -(0.2e1 * p3 * Dphi ^ 2 * sin(-theta + phi) * p2 ...
        * Dtheta - 0.2e1 * Dphi * p2 ^ 2 * cos(-theta + phi)...
        * Dtheta * sin(-theta + phi)) ...
        / (-p1 * p3 + cos(-theta + phi) ^ 2 * p2 ^ 2);
   
    A = [a11 a12 a13; a21 a22 a23; a31 a32 a33];

    Dzeta = A*zeta;
end
