function zeta_p = transverse_linearization_discrete(zeta_n, ...
    theta_inputs_to_phi, phi_evaluated_at_theta, ...
    Dphi_evaluated_at_theta, time_inputs_to_theta, ...
    theta_evaluated_at_time, Dtheta_evaluated_at_time, gait_period,E0)
    
    global p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 psi;

    %% Right before impact t=T
    thetaT = interp1(time_inputs_to_theta, theta_evaluated_at_time, ...
        gait_period, 'spline');
    DthetaT = interp1(time_inputs_to_theta, Dtheta_evaluated_at_time, ...
        gait_period, 'spline');
    temp = aby_weighted(gait_period, [thetaT,DthetaT], ...
        theta_inputs_to_phi, phi_evaluated_at_theta, ...
        Dphi_evaluated_at_theta); 
    DDthetaT = temp(2);

    phiT = interp1(theta_inputs_to_phi, phi_evaluated_at_theta, ...
        thetaT, 'spline');
    DphiT = interp1(theta_inputs_to_phi, Dphi_evaluated_at_theta, ...
        thetaT, 'spline');
    temp = f0(thetaT,[phiT,DphiT], E0);
    DDphiT = temp(2);

    %% Right after impact t=0
    theta0 = interp1(time_inputs_to_theta, theta_evaluated_at_time, ...
        0, 'spline');
    Dtheta0 = interp1(time_inputs_to_theta, Dtheta_evaluated_at_time,...
        0, 'spline');
    temp = aby_weighted(0, [theta0,Dtheta0], theta_inputs_to_phi,...
        phi_evaluated_at_theta, Dphi_evaluated_at_theta); 
    DDtheta0 = temp(2);

    phi0 = interp1(theta_inputs_to_phi, phi_evaluated_at_theta,...
        theta0, 'spline');
    Dphi0 = interp1(theta_inputs_to_phi, Dphi_evaluated_at_theta,...
        theta0, 'spline');
    temp = f0(theta0,[phi0,Dphi0], E0);
    DDphi0 = temp(2);
      
    %% Solving for generalized coordinates
    q1p = theta0;
    Dq1p = Dtheta0;
    DDq1p = DDtheta0;
    
    q2p = phi0;
    Dq2p = Dphi0*Dtheta0;
    DDq2p = DDphi0*Dtheta0^2 + Dphi0*DDtheta0;

    q1n = thetaT;
    Dq1n = DthetaT;
    DDq1n = DDthetaT;
    
    q2n = phiT;
    Dq2n = DphiT*DthetaT;
    DDq2n = DDphiT*DthetaT^2 + DphiT*DDthetaT;
    
    %% Linearized impact map
    df_ts11 = -Dq1p * cos(q1n - q2n) * (p8 * p10 - p7 * p9) ...
        / (-p8 * p6 + cos(q1n - q2n) ^ 2 * p7 ^ 2) / Dq1n ...
        + Dq1p * p8 / (-p8 * p6 + cos(q1n - q2n) ^ 2 ...
        * p7 ^ 2) * p11 * Dq2n / Dq1n ^ 2;
    df_ts12 = -0.2e1 * Dq1p * sin(q1n - q2n) ...
        * (Dq1n * p8 * cos(q1n - q2n) ^ 2 * p7 ^ 2 ...
        * p10 + Dq1n * p8 ^ 2 * p10 * p6 - Dq1n * p7 ...
        * p9 * p8 * p6 - Dq1n * p7 ^ 3 * p9 ...
        * cos(q1n - q2n) ^ 2 - 0.2e1 * p8 * p11 * Dq2n ...
        * cos(q1n - q2n) * p7 ^ 2) / (p8 ^ 2 * p6 ^ 2 ...
        - 0.2e1 * p8 * p6 * cos(q1n - q2n) ^ 2 * p7 ^ 2 ...
        + cos(q1n - q2n) ^ 4 * p7 ^ 4) * sin(q2n + psi) ...
        * Dq1n / (Dq1n * sin(q1n + psi) - Dq2n ...
        * sin(q2n + psi)) + (-(2 * DDq1p) + 0.2e1 ...
        * Dq1p * sin(q1n - q2n) * (Dq1n * p8 ...
        * cos(q1n - q2n) ^ 2 * p7 ^ 2 * p10 + Dq1n ...
        * p8 ^ 2 * p10 * p6 - Dq1n * p7 * p9 * p8 * p6 ...
        - Dq1n * p7 ^ 3 * p9 * cos(q1n - q2n) ^ 2 ...
        - 0.2e1 * p8 * p11 * Dq2n * cos(q1n - q2n) ...
        * p7 ^ 2) / (p8 ^ 2 * p6 ^ 2 - 0.2e1 * p8 * p6 ...
        * cos(q1n - q2n) ^ 2 * p7 ^ 2 + cos(q1n - q2n) ^ 4 ...
        * p7 ^ 4)) * Dq1n * sin(q1n + psi) / (Dq1n ...
        * sin(q1n + psi) - Dq2n * sin(q2n + psi)) ...
        - 0.2e1 * Dq1p * cos(q1n - q2n) * (p8 * p10 ...
        - p7 * p9) / (-p8 * p6 + cos(q1n - q2n) ^ 2 ...
        * p7 ^ 2) * sin(q2n + psi) * DDq1n / (Dq1n ...
        * sin(q1n + psi) - Dq2n * sin(q2n + psi)) + 0.2e1 ...
        * Dq1p * p8 / (-p8 * p6 + cos(q1n - q2n) ^ 2 ...
        * p7 ^ 2) * p11 * sin(q2n + psi) * DDq2n / (Dq1n ...
        * sin(q1n + psi) - Dq2n * sin(q2n + psi));
    df_ts13 = 0.2e1 * Dq1p * p8 ...
        / (-p8 * p6 + cos(q1n - q2n) ^ 2 * p7 ^ 2) * p11;
    df_ts21 = 0;
    df_ts22 = sin(q2n + psi) * Dq1n ...
        / (Dq1n * sin(q1n + psi) - Dq2n ...
        * sin(q2n + psi)) - Dq2p / Dq1p * Dq1n ...
        * sin(q1n + psi) / (Dq1n * sin(q1n + psi) ...
        - Dq2n * sin(q2n + psi));
    df_ts23 = 0;
    df_ts31 = (Dq2p / Dq1p * cos(q1n - q2n)...
        * (p8 * p10 - p7 * p9) / (-p8 * p6 ...
        + cos(q1n - q2n) ^ 2 * p7 ^ 2) ...
        - (cos(q1n - q2n) ^ 2 * p7 * p10 - p9 * p6) ...
        / (-p8 * p6 + cos(q1n - q2n) ^ 2 * p7 ^ 2)) ...
        / Dq1n / 0.2e1 + (-Dq2p / Dq1p * p8 ...
        / (-p8 * p6 + cos(q1n - q2n) ^ 2 * p7 ^ 2) ...
        * p11 + cos(q1n - q2n) * p7 / (-p8 * p6 ...
        + cos(q1n - q2n) ^ 2 * p7 ^ 2) * p11) ...
        * Dq2n / Dq1n ^ 2 / 0.2e1;
    df_ts32 = (Dq2p / Dq1p * sin(q1n - q2n) ...
        * (Dq1n * p8 * cos(q1n - q2n) ^ 2 * p7 ^ 2 ...
        * p10 + Dq1n * p8 ^ 2 * p10 * p6 - Dq1n * p7 ...
        * p9 * p8 * p6 - Dq1n * p7 ^ 3 * p9 ...
        * cos(q1n - q2n) ^ 2 - 0.2e1 * p8 * p11 ...
        * Dq2n * cos(q1n - q2n) * p7 ^ 2) / (p8 ^ 2 ...
        * p6 ^ 2 - 0.2e1 * p8 * p6 * cos(q1n - q2n) ^ 2 ...
        * p7 ^ 2 + cos(q1n - q2n) ^ 4 * p7 ^ 4) ...
        - sin(q1n - q2n) * p7 * (0.2e1 * cos(q1n - q2n) ...
        * p6 * Dq1n * p8 * p10 - 0.2e1 * cos(q1n - q2n) ...
        * p6 * Dq1n * p7 * p9 - p11 * Dq2n * p8 * p6 ...
        - cos(q1n - q2n) ^ 2 * p7 ^ 2 * p11 * Dq2n) ...
        / (p8 ^ 2 * p6 ^ 2 - 0.2e1 * p8 * p6 ...
        * cos(q1n - q2n) ^ 2 * p7 ^ 2 ...
        + cos(q1n - q2n) ^ 4 * p7 ^ 4)) * sin(q2n + psi) ...
        * Dq1n / (Dq1n * sin(q1n + psi) - Dq2n ...
        * sin(q2n + psi)) + ((-DDq2p * Dq1p ...
        + Dq2p * DDq1p) / Dq1p ^ 2 - Dq2p / Dq1p ...
        * sin(q1n - q2n) * (Dq1n * p8 * cos(q1n - q2n) ^ 2 ...
        * p7 ^ 2 * p10 + Dq1n * p8 ^ 2 * p10 * p6 ...
        - Dq1n * p7 * p9 * p8 * p6 - Dq1n * p7 ^ 3 ...
        * p9 * cos(q1n - q2n) ^ 2 - 0.2e1 * p8 * p11 ...
        * Dq2n * cos(q1n - q2n) * p7 ^ 2) / (p8 ^ 2 ...
        * p6 ^ 2 - 0.2e1 * p8 * p6 * cos(q1n - q2n) ^ 2 ...
        * p7 ^ 2 + cos(q1n - q2n) ^ 4 * p7 ^ 4) ...
        + sin(q1n - q2n) * p7 * (0.2e1 * cos(q1n - q2n) ...
        * p6 * Dq1n * p8 * p10 - 0.2e1 * cos(q1n - q2n) ...
        * p6 * Dq1n * p7 * p9 - p11 * Dq2n * p8 * p6 ...
        - cos(q1n - q2n) ^ 2 * p7 ^ 2 * p11 * Dq2n) ...
        / (p8 ^ 2 * p6 ^ 2 - 0.2e1 * p8 * p6 ...
        * cos(q1n - q2n) ^ 2 * p7 ^ 2 + cos(q1n - q2n) ^ 4 ...
        * p7 ^ 4)) * Dq1n * sin(q1n + psi) ...
        / (Dq1n * sin(q1n + psi) - Dq2n * sin(q2n + psi)) ...
        + (Dq2p / Dq1p * cos(q1n - q2n) * (p8 * p10 - p7 * p9) ...
        / (-p8 * p6 + cos(q1n - q2n) ^ 2 * p7 ^ 2) ...
        - (cos(q1n - q2n) ^ 2 * p7 * p10 - p9 * p6) ...
        / (-p8 * p6 + cos(q1n - q2n) ^ 2 * p7 ^ 2)) ...
        * sin(q2n + psi) * DDq1n / (Dq1n * sin(q1n + psi) ...
        - Dq2n * sin(q2n + psi)) + (-Dq2p / Dq1p * p8 ...
        / (-p8 * p6 + cos(q1n - q2n) ^ 2 * p7 ^ 2) * p11 ...
        + cos(q1n - q2n) * p7 / (-p8 * p6 + cos(q1n - q2n) ^ 2 ...
        * p7 ^ 2) * p11) * sin(q2n + psi) * DDq2n ...
        / (Dq1n * sin(q1n + psi) - Dq2n * sin(q2n + psi));
    df_ts33 = -Dq2p / Dq1p * p8 / (-p8 * p6 ...
        + cos(q1n - q2n) ^ 2 * p7 ^ 2) * p11 ...
        + cos(q1n - q2n) * p7 ...
        / (-p8 * p6 + cos(q1n - q2n) ^ 2 * p7 ^ 2) * p11;


    dF_TS = [df_ts11 df_ts12 df_ts13; df_ts21 ...
        df_ts22 df_ts23; df_ts31 df_ts32 df_ts33];

    zeta_p = dF_TS*zeta_n;
end

