function plot_angles(time, q, Dq, impacts)
    fig = figure(10003);
    
    set(0,'Units','pixels');
    scnsize = get(0,'ScreenSize');
    
    screen_width = scnsize(3);
    screen_height = scnsize(4);
    
    pos = [ 2/3*screen_width,...    % Bottom left corner x - pos
            0.5*screen_height,...   % Bottom left corner y - pos
            1/3*screen_width,...    % Figure width
            0.5*screen_height];     % Figure height
    set(fig,'OuterPosition',pos);
    


    subplot1_handle = subplot(2,1,1);
    hold on;
    plot(time, q(:,1), 'r');      % Stance leg
    plot(time, q(:,2), 'g');      % Swing leg
    plot1_axis = axis;
    title('Angles and angular velocities');
    xlabel('Elapsed time [s]');
    ylabel('q(t) [rad]');

    hold off;
    
    subplot2_handle = subplot(2,1,2);
    hold on;
    plot(time, Dq(:,1), 'r');   % Stance leg
    plot(time, Dq(:,2), 'g');   % Swing leg
    plot2_axis = axis;
    xlabel('Elapsed time [s]');
    ylabel('$$\dot{q}$$ [rad/s]');
    hold off;

    axis manual;
    subplot(2,1,1), line([impacts(:,1), impacts(:,1)]', ...
        [plot1_axis(3)*ones(size(impacts,1),1),...
        plot1_axis(4)*ones(size(impacts,1),1)]', ...
        'LineStyle', ':', 'Color', 'b');
    subplot(2,1,2), line([impacts(:,1), impacts(:,1)]', ...
        [plot2_axis(3)*ones(size(impacts,1),1), ...
        plot2_axis(4)*ones(size(impacts,1),1)]', ...
        'LineStyle', ':', 'Color', 'b');
    
    hold off;  

    legend(subplot1_handle, {'$q_1(t)$','$q_2(t)$','Impact'},...
        'Location','SouthWest','Orientation','Horizontal',...
        'Interpreter', 'LaTex');
    legend(subplot2_handle, {'$\dot{q}_1(t)$','$\dot{q}_2(t)$',...
        'Impact'},'Location','SouthWest','Orientation','Horizontal', ...
        'Interpreter', 'LaTex');

end

