function plot_eigenvalues(eigenvalues)
     fig = figure(10010);
    
    set(0,'Units','pixels');
    scnsize = get(0,'ScreenSize');
    
    screen_width = scnsize(3);
    screen_height = scnsize(4);
    
    pos = [ 0,...                   % Bottom left corner x - pos
            0.5*screen_height,...   % Bottom left corner y - pos
            1/3*screen_width,...    % Figure width
            0.5*screen_height];     % Figure height
    set(fig,'OuterPosition',pos) 
    
    handles = zeros(4,1);
    
    hold on;
    for i = 1:length(eigenvalues)
        handles(i) = plot(real(eigenvalues(i)),imag(eigenvalues(i)),'o');
    end
   
    handles(4) = plot(cos(0:0.01:2*pi),sin(0:0.01:2*pi),'r');
   
    unit_circle_radius = 1;
    padding = 0.2;
    
    min_xy = min(-(unit_circle_radius + padding), ...
        min(min(imag(eigenvalues)),min(real(eigenvalues))));
    max_xy = max((unit_circle_radius + padding), ...
        max(max(imag(eigenvalues)),max(real(eigenvalues))));
    
    if(max(abs(eigenvalues))) > (unit_circle_radius + padding)
        min_xy = -(max(abs(eigenvalues)) + padding);
        max_xy = max(abs(eigenvalues)) + padding;
    end
    
    axis([min_xy max_xy min_xy max_xy]);
    
    line([0 0],[min_xy max_xy],'Color','k');
    line([min_xy max_xy],[0 0],'Color','k');
    
    title('Eigenvalues of transition matrix');
    xlabel('Re');
    ylabel('Im');
    legend([handles(1) handles(end)],{'Eigenvalues','Unit circle'});
    hold off;   
end
