function plot_phase_portrait(q, Dq, impacts)
    
    fig = figure(10002);
    
    set(0,'Units','pixels');
    scnsize = get(0,'ScreenSize');
    
    screen_width = scnsize(3);
    screen_height = scnsize(4);
    
    pos = [ 1/3*screen_width,...    % Bottom left corner x - pos
            0.5*screen_height,...   % Bottom left corner y - pos
            1/3*screen_width,...    % Figure width
            0.5*screen_height];     % Figure height
    set(fig,'OuterPosition',pos) 
    
    hold on;
    previous_impact_index = 1;
    
    for index = 1:size(impacts,1)
        next_impact_index = impacts(index, 2);
        
        % Stance leg
        plot(q(previous_impact_index+1:next_impact_index,1),...
            Dq(previous_impact_index+1:next_impact_index,1), 'r'); 
        % Swing leg
        plot(q(previous_impact_index+1:next_impact_index,2),...
            Dq(previous_impact_index+1:next_impact_index,2), 'g');      
        
        line([q(next_impact_index,1), q(next_impact_index+1,2)],...
            [Dq(next_impact_index,1), Dq(next_impact_index+1,2)],...
            'LineStyle',':','Color', 'b');
        line([q(next_impact_index,2), q(next_impact_index+1,1)],...
            [Dq(next_impact_index,2), Dq(next_impact_index+1,1)],...
            'LineStyle',':','Color', 'b');
        plot(q(next_impact_index,1),Dq(next_impact_index,1),'ob');
        plot(q(next_impact_index,2),Dq(next_impact_index,2),'ob');
        plot(q(next_impact_index+1,1),Dq(next_impact_index+1,1),'ob');
        plot(q(next_impact_index+1,2),Dq(next_impact_index+1,2),'ob');
        
        previous_impact_index = next_impact_index;
    end
    
    % Stance leg
    plot(q(previous_impact_index+1:end,1),...
        Dq(previous_impact_index+1:end,1), 'r');
    % Swing leg
    plot(q(previous_impact_index+1:end,2),...
        Dq(previous_impact_index+1:end,2), 'g');      
    
    hold off;
    
    title('Phase portrait');
    xlabel('q [rad]');
    ylabel('$$\dot{q}$$ [rad]');
    legend({'Stance leg','Swing leg','Impact'},'Location',...
        'SouthWest','Orientation','Horizontal', 'Interpreter', 'LaTex');
end

