clc;
clear all;
close all;
set(0,'defaulttextinterpreter','LaTex')

run physical_parameters;

%% Search for periodic gait
% Initital guess for a,b and choice of solution for quadratic equation n = {1,2}

% Stable
a0 = 0.2;
b0 = -1.0;
quad_solution_selector = 2;

% Unstable
% a0 = 0.2;
% b0 = -1.0;
% quad_solution_selector = 1;

% Non-feasible gait, traveling upwards
% a0 = 0.2;
% b0 = 1.0;
% quad_solution_selector = 2;

% Search for gait near initial conditions
[a,b,c,d,e,f,g,h,E0] = run_gait_search(a0, b0, quad_solution_selector);

% Define perturbations
% EPSILON_q0 = 0.01;
% EPSILON_Dq0 = 0.01;
EPSILON_q0 = 0;
EPSILON_Dq0 = 0;

q0 = [a; e] + EPSILON_q0;
Dq0 = [b; f] + EPSILON_Dq0;

fprintf('*****************************************************************\n');
fprintf('Periodic gait found, starting simulation with initial conditions:\n');
fprintf('q10 = %f\nq20 = %f\nDq10 = %f\nDq20 = %f\n', q0(1),q0(2),Dq0(1),Dq0(2));
fprintf('*****************************************************************\n');

%% Simulate periodic gait

x0 = [q0;Dq0];

MAP_SELECTOR = 1; 
% 1 = Conservation of angular momentum
% 2 = Integration of dynamics

SIMULATION_TIME = 30;
DRAW_INTERVAL = 0.05;  % Interval in seconds 
                       % between state space plotting

REPEATS = 0;           % Animation repeats
FPS = 24;              % Animation playback fps

T0 = 0;
tspan = [T0 SIMULATION_TIME];

state_space = [];
time = [];
impacts = [];
last_impact = 0;
gait_period = [];

current_time = T0;

while(current_time < SIMULATION_TIME)

    options = odeset('Events', @impact_event);
    [tout, xout, event_time, event_state, event_id] = ode45(...
        @equations_of_motion, tspan, x0, options);
    
    if ~isempty(event_id) && event_time(end) == tout(end)
        impact_time = tout(end);
        impact_index = length(time)+length(tout);
        
        impacts = [impacts; impact_time, impact_index];
        gait_period = [gait_period; impact_time - last_impact];
        last_impact = impact_time;
        x0 = impact_map(xout(end,:), MAP_SELECTOR);
        
        fprintf('*************************************************\n');
        fprintf('Impact surface hit at time = %0.2f\n', impact_time);
        fprintf('Index = %d\n', impact_index);
        fprintf('q1 = %0.2f\n', xout(end,1)*180/pi);
        fprintf('q2 = %0.2f\n', xout(end,2)*180/pi);
        fprintf('*************************************************\n');
    end
    
    time = [time; tout];
    state_space = [state_space; xout];
    
    tspan = [time(end) max(SIMULATION_TIME, time(end))];
    current_time = time(end);
end

%% Visualize walker movement and energy
plot_gait_period(gait_period, impacts);
plot_phase_portrait(state_space(:,1:2),state_space(:,3:4),impacts);
plot_angles(time, state_space(:,1:2), state_space(:,3:4),impacts);
plot_travel(time, impacts, state_space, DRAW_INTERVAL, REPEATS, FPS);
